Changelog
=========

0.2.0 (2016-07-29)
------------------

* Tasks were fixed to work with ``invoke >= 0.13.0``.
* New task ``check_if_dirty`` was added. Make your tasks depend on it,
  and execution will be interrupted if some git changes aren't commited and pushed.

0.1.0 (2016-02-10)
------------------

* First release on PyPI.
